Changelog
=========

## 1.0.0-alpha.2

* proceed with renderer for xml and json
* add metadata for embeddable flavour
* images accessible via URL
* add configurable methods for processing
* improve geometry handling
* add documentation on https://camptocamp.github.io/pyramid_oereb/doc/
* several bugfixes

## 1.0.0-alpha.1

* first running approach of server
* main web services are available (not all formats are implemented yet)
* standard configuration can be used to run server out of the box
* see README for more details

## 0.0.1

* initial version